Param

Enum Param 

pub enum Param {
    Null,
    Integer(i64),
    Real(f64),
    Text(String),
    Blob(Vec<u8>),
    StmtOutputIndexed(usize, usize),
    StmtOutputNamed(usize, Cow<'static, str>),
}
Available on crate feature sqlite and (crate features cache or sqlite) only.

Variants



Null

The value is a NULL value.



Integer(i64)

The value is a signed integer.



Real(f64)

The value is a floating point number.



Text(String)

The value is a text string.



Blob(Vec<u8>)

The value is a blob of data



StmtOutputIndexed(usize, usize)

The value is a variable referencing the first row of a previous statement in a transaction. The key is the statement index and a column index.



StmtOutputNamed(usize, Cow<'static, str>)

The value is a variable referencing the first row of a previous statement in a transaction. The key is the statement index and a column name.