start_node_with_cache

Function start_node_with_cache 

pub async fn start_node_with_cache<C>(
    node_config: NodeConfig,
) -> Result<Client, Error>
where C: Debug + CacheVariants,
Available on crate feature cache only.
The main entry function to start a Raft / Hiqlite node. With the cache feature enabled, you need to provide the generic enum which will function as the Cache Index value to decide between multiple caches.

Panics

If an incorrect node_config was given.